==> jscommunicator-1.0.21.tgz: package/lib/genericPromotionalSms.js <==
"use strict";

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var base = require('./base');
var types = require('./types');

var SmsGenericPromotional = function (_base$Base) {
  _inherits(SmsGenericPromotional, _base$Base);

  function SmsGenericPromotional(host, config, appName) {
    _classCallCheck(this, SmsGenericPromotional);

    return _possibleConstructorReturn(this, (SmsGenericPromotional.__proto__ || Object.getPrototypeOf(SmsGenericPromotional)).call(this, host, config, appName));
  }

  _createClass(SmsGenericPromotional, [{
    key: 'sendSms',
    value: function sendSms(referenceId, referenceType, name, to, messageType, body, initiatedAt) {
      var expiryTime = arguments.length > 7 && arguments[7] !== undefined ? arguments[7] : null;
      var senderId = arguments.length > 8 && arguments[8] !== undefined ? arguments[8] : null;

      var job = new types.GenericPromotionalSms();
      job.reference_id = referenceId;
      job.reference_type = referenceType;
      job.name = name;
      job.mobile = to;
      job.app_name = this.appName;
      job.message_type = messageType.toUpperCase();
      job.message_text = body;
      job.initiated_at = body;
      job.expiry_time = expiryTime;
      job.sender_id = senderId;
      job.sms_type = 'generic_promotional';
      this.send(job, this.queueNames.sendGenericPromotionalSmsQueue, 0);
    }
  }, {
    key: 'getMessagesByReferenceId',
    value: function getMessagesByReferenceId(referenceId, smsTypes, callback) {
      if (!Array.isArray(smsTypes)) {
        throw "smsTypes should be array";
      }
      var data = {};
      data.reference_id = referenceId;
      data.sms_types = JSON.stringify(smsTypes);
      this.get('/genericpromotionalsms/get_messages_by_reference_id', data, function (err, response) {
        if (err) {
          callback(err);
        } else {
          callback(null, response);
        }
      });
    }
  }, {
    key: 'isMessageSentOfTypeForRecipient',
    value: function isMessageSentOfTypeForRecipient(messageType, mobile, callback) {
      var data = {};
      data.message_type = messageType;
      data.mobile = mobile;
      this.get('/genericpromotionalsms/is_msg_sent_of_type_for_recipient', data, function (err, response) {
        if (err) {
          callback(err);
        } else {
          callback(null, response);
        }
      });
    }
  }, {
    key: 'getMessageCountByType',
    value: function getMessageCountByType(messageType, startDate, endDate, status, callback) {
      var data = {};
      data.message_type = messageType;
      data.start_date = startDate;
      data.end_date = endDate;
      data.status = status;
      var response = this.get('/genericpromotionalsms/get_message_count_for_type', data, function (err, response) {
        if (err) {
          callback(err);
        } else {
          callback(null, response);
        }
      });
    }
  }, {
    key: 'getMessageCountByReferenceIds',
    value: function getMessageCountByReferenceIds(referenceIds, smsTypes, callback) {
      if (!Array.isArray(referenceIds)) {
        throw "referenceIds should be array";
      }
      if (!Array.isArray(smsTypes)) {
        throw "smsTypes should be array";
      }
      var data = {};
      data.reference_ids = JSON.stringify(referenceIds);
      data.sms_types = JSON.stringify(smsTypes);
      this.get('/genericpromotionalsms/get_message_count_by_reference_ids', data, function (err, response) {
        if (err) {
          callback(err);
        } else {
          callback(null, response);
        }
      });
    }
  }, {
    key: 'validateSmsType',
    value: function validateSmsType(type) {
      var allowedTypes = ['VN_APP_PROMOTION_SMS', 'FIT_RAY_SHARE_SMS', 'PHR_TAX_SAVING_NOTIFICATION_SMS'];

      if (allowedTypes.indexOf(type) < 0) {
        throw "Invalid mail type";
      }
    }
  }]);

  return SmsGenericPromotional;
}(base.Base);

module.exports = {
  SmsGenericPromotional: SmsGenericPromotional
};

==> jscommunicator-1.0.27.tgz: package/lib/genericPromotionalSms.js <==
"use strict";

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var base = require('./base');
var types = require('./types');

var SmsGenericPromotional = function (_base$Base) {
  _inherits(SmsGenericPromotional, _base$Base);

  function SmsGenericPromotional(request, config, appName) {
    _classCallCheck(this, SmsGenericPromotional);

    return _possibleConstructorReturn(this, (SmsGenericPromotional.__proto__ || Object.getPrototypeOf(SmsGenericPromotional)).call(this, request, config, appName));
  }

  _createClass(SmsGenericPromotional, [{
    key: 'sendSms',
    value: function sendSms(referenceId, referenceType, name, to, messageType, body, initiatedAt) {
      var expiryTime = arguments.length > 7 && arguments[7] !== undefined ? arguments[7] : null;
      var senderId = arguments.length > 8 && arguments[8] !== undefined ? arguments[8] : null;
      var campaignId = arguments.length > 9 && arguments[9] !== undefined ? arguments[9] : null;

      var job = new types.GenericPromotionalSms();
      job.reference_id = referenceId;
      job.reference_type = referenceType;
      job.name = name;
      job.mobile = to;
      job.app_name = this.appName;
      job.message_type = messageType.toUpperCase();
      job.message_text = body;
      job.initiated_at = body;
      job.expiry_time = expiryTime;
      job.sender_id = senderId;
      job.campaign_id = campaignId;
      job.sms_type = 'generic_promotional';
      this.send(job, this.queueNames.sendGenericPromotionalSmsQueue, 0);
    }
  }, {
    key: 'getMessagesByReferenceId',
    value: function getMessagesByReferenceId(referenceId, smsTypes, callback) {
      if (!Array.isArray(smsTypes)) {
        throw "smsTypes should be array";
      }
      var data = {};
      data.reference_id = referenceId;
      data.sms_types = JSON.stringify(smsTypes);
      this.get('/genericpromotionalsms/get_messages_by_reference_id', data, function (err, response) {
        if (err) {
          callback(err);
        } else {
          callback(null, response);
        }
      });
    }
  }, {
    key: 'isMessageSentOfTypeForRecipient',
    value: function isMessageSentOfTypeForRecipient(messageType, mobile, callback) {
      var data = {};
      data.message_type = messageType;
      data.mobile = mobile;
      this.get('/genericpromotionalsms/is_msg_sent_of_type_for_recipient', data, function (err, response) {
        if (err) {
          callback(err);
        } else {
          callback(null, response);
        }
      });
    }
  }, {
    key: 'getMessageCountByType',
    value: function getMessageCountByType(messageType, startDate, endDate, status, callback) {
      var data = {};
      data.message_type = messageType;
      data.start_date = startDate;
      data.end_date = endDate;
      data.status = status;
      var response = this.get('/genericpromotionalsms/get_message_count_for_type', data, function (err, response) {
        if (err) {
          callback(err);
        } else {
          callback(null, response);
        }
      });
    }
  }, {
    key: 'getMessageCountByReferenceIds',
    value: function getMessageCountByReferenceIds(referenceIds, smsTypes, callback) {
      if (!Array.isArray(referenceIds)) {
        throw "referenceIds should be array";
      }
      if (!Array.isArray(smsTypes)) {
        throw "smsTypes should be array";
      }
      var data = {};
      data.reference_ids = JSON.stringify(referenceIds);
      data.sms_types = JSON.stringify(smsTypes);
      this.get('/genericpromotionalsms/get_message_count_by_reference_ids', data, function (err, response) {
        if (err) {
          callback(err);
        } else {
          callback(null, response);
        }
      });
    }
  }, {
    key: 'validateSmsType',
    value: function validateSmsType(type) {
      var allowedTypes = ['VN_APP_PROMOTION_SMS', 'FIT_RAY_SHARE_SMS', 'PHR_TAX_SAVING_NOTIFICATION_SMS'];

      if (allowedTypes.indexOf(type) < 0) {
        throw "Invalid mail type";
      }
    }
  }]);

  return SmsGenericPromotional;
}(base.Base);

module.exports = {
  SmsGenericPromotional: SmsGenericPromotional
};
